@@ -3,11 +3,10 @@ from __future__ import annotations
 from typing import Any, AsyncIterator, Dict, List, Optional, TYPE_CHECKING, Union
 
 from mi.emoji import Emoji
+from mi.instance import Instance
 from mi.models.user import RawUser
 from mi.types.user import (Channel as ChannelPayload, FieldContent as FieldContentPayload, PinnedNote as PinnedNotePayload,
                            PinnedPage as PinnedPagePayload)
-from mi.instance import Instance
-
 
 if TYPE_CHECKING:
     from mi import ConnectionState
@@ -311,4 +310,4 @@ class User:
 
     @property
     def action(self):
-        return self.__state.get_user_instance(self.__raw_user.id, user=self)
+        return self.__state.get_user_instance(self.__raw_user.id, self)
